'use strict';

function TrackForm(props) {
  if (props.show) {
    return null
  }
  return (
    <div>
      <h1 className="text-2xl font-semibold text-gray-600 pb-5">Track Order</h1>
      <form action="">
        <div className="flex flex-col space-y-1">
          <label htmlFor="username" className="text-sm font-bold text-gray-500">Tracking Number</label>
          <div className="relative">
            <input type="text"
              className="block appearance-none tracking-wide w-full bg-gray-100 border border-gray-100 text-gray-500 py-3 px-4 pr-8 rounded" placeholder="Enter tracking number" />
          </div>
        </div>
        {!this.state.show && <div className="text-center mt-5">
          <button onClick={this.onSubmit}
            disabled={this.state.isLoading}
            className="inline-block bg-green-700 text-green-100 font-medium uppercase py-3 shadow px-16 rounded-md">{this.state.isLoading ? "Tracking..." : "Start Tracking"}</button>
        </div>}
      </form>
    </div>
  )
}


// Datetime formating 
function DateFormat(props) {
  const date_time = moment(props.date).format('MMMM Do YYYY, h:mm:ss a')
  return (
    <p className="leading-tight text-xs text-justify text-gray-500">
      Updated: {date_time}
    </p>
  )
}

function TrackOrderResult(props) {

  if (!props.show) {
    return null
  }

  return (

    <div className="">
      {/* <!-- INFO BAR --> */}
      <div class="bg-red-500 ">
        <div class="flex flex-col px-6 py-3">
          <h1 class="text-2xl text-red-100 font-bold">
            {props.business} application successfully submitted</h1>
          <p class="text-sm text-red-200 font-medium">
            Please check your email for further information</p>

        </div>
      </div>
    </div>

  )
}

class ApplicantForm extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      error: '',
      isLoading: false,
      show: false,
      list: [],
      business_name: '',
      email: '',
      phone_number: '',
    };
    // this.handleToggleClick = this.handleToggleClick.bind(this);
  }


  onSubmit = event => {
    const applicant = {
      business_name: this.state.business_name,
      email: this.state.email,
      phone_number: this.state.phone_number,
      price_plan:"Silver",
    };
    this.setState({ isLoading: true });
    axios.post(`https://maserumetro.com/business-api/`, applicant)
    // axios.post(`http://localhost:8000/business-api/`, applicant)
      .then(list => {
        this.setState({
          isLoading: false,
          list: list.data,
          show: true
        });
        console.log(list.data)

      }).catch((errors) => {
        this.setState({ isLoading: false, error: 'please enter correct information' })
      });
    event.preventDefault();
  };

  render() {

    return (
      <div>

        <TrackOrderResult show={this.state.show} business={this.state.business_name} />
        {!this.state.show && <div>
          {/* <!-- INFO BAR --> */}
          <div class="bg-gray-200 ">
            <div class="flex flex-col px-6 py-3">

              <h1 class="text-2xl text-gray-700 font-bold">
                Let's get started</h1>
              <p class="text-xs text-gray-600 font-medium">
                Provide your business information</p>

            </div>
          </div>
          {/* <!-- END INFO BAR -->
              <!-- BODY FORM --> */}
          <div class="p-6 overflow-y">
            <form onSubmit={this.onSubmit}>

              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ business_name: event.target.value })} type="text" name="name" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="name" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Business
                      Name</label>
                <span class="text-sm text-red-600 hidden" id="error">Business Name is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ email: event.target.value })} type="text" name="email" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="email" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Email</label>
                <span class="text-sm text-red-600 hidden" id="error">Business email is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ phone_number: event.target.value })}
                  type="text" name="phone" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="phone" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Phone Number</label>
                <span class="text-sm text-red-600 hidden" id="error">Phone number is
                      required</span>
              </div>

              <button id="button" type="submit"
                class="w-90 px-6 py-1 mt-3 text-lg text-gray-600 transition-all duration-150 ease-linear  shadow-sm rounded-full outline-none bg-gray-200 hover:bg-gray-300 hover:shadow-lg focus:outline-none tracking-wide">
                {this.state.isLoading ? "submitting application..." : "Submit"}
              </button>

            </form>
          </div>
        </div>
        }
      </div>
    )
  }
}
// Platinum Form
class ApplicantFormPlatinum extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      error: '',
      isLoading: false,
      show: false,
      list: [],
      business_name: '',
      email: '',
      phone_number: '',
    };
    // this.handleToggleClick = this.handleToggleClick.bind(this);
  }


  onSubmit = event => {
    const applicant = {
      business_name: this.state.business_name,
      email: this.state.email,
      phone_number: this.state.phone_number,
      price_plan:"Platinum",
    };
    this.setState({ isLoading: true });
    axios.post(`https://maserumetro.com/business-api/`, applicant)
      .then(list => {
        this.setState({
          isLoading: false,
          list: list.data,
          show: true
        });
        console.log(list.data)

      }).catch((errors) => {
        this.setState({ isLoading: false, error: 'please enter correct information' })
      });
    event.preventDefault();
  };

  render() {

    return (
      <div>

        <TrackOrderResult show={this.state.show} business={this.state.business_name} />
        {!this.state.show && <div>
          {/* <!-- INFO BAR --> */}
          <div class="bg-gray-800 ">
            <div class="flex flex-col px-6 py-3">

              <h1 class="text-2xl text-gray-100 font-bold">
                Let's get started</h1>
              <p class="text-xs text-gray-200 font-medium">
                Provide your business information</p>

            </div>
          </div>
          {/* <!-- END INFO BAR -->
              <!-- BODY FORM --> */}
          <div class="p-6 overflow-y">
            <form onSubmit={this.onSubmit}>

              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ business_name: event.target.value })} type="text" name="name" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="name" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Business
                      Name</label>
                <span class="text-sm text-red-600 hidden" id="error">Business Name is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ email: event.target.value })} type="text" name="email" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="email" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Email</label>
                <span class="text-sm text-red-600 hidden" id="error">Business email is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ phone_number: event.target.value })}
                  type="text" name="phone" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="phone" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Phone Number</label>
                <span class="text-sm text-red-600 hidden" id="error">Phone number is
                      required</span>
              </div>

              <button id="button" type="submit"
                class="w-90 px-6 py-1 mt-3 text-lg text-gray-200 transition-all duration-150 ease-linear  shadow-sm rounded-full outline-none bg-gray-800 hover:bg-gray-600 hover:shadow-lg focus:outline-none tracking-wide">
                {this.state.isLoading ? "submitting application..." : "Submit"}
              </button>

            </form>
          </div>
        </div>
        }
      </div>
    )
  }
}
class ApplicantFormGold extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      error: '',
      isLoading: false,
      show: false,
      list: [],
      business_name: '',
      email: '',
      phone_number: '',
    };
    // this.handleToggleClick = this.handleToggleClick.bind(this);
  }


  onSubmit = event => {
    const applicant = {
      business_name: this.state.business_name,
      email: this.state.email,
      phone_number: this.state.phone_number,
      price_plan:"Gold",
    };
    this.setState({ isLoading: true });
    axios.post(`https://maserumetro.com/business-api/`, applicant)
      .then(list => {
        this.setState({
          isLoading: false,
          list: list.data,
          show: true
        });
        console.log(list.data)

      }).catch((errors) => {
        this.setState({ isLoading: false, error: 'please enter correct information' })
      });
    event.preventDefault();
  };

  render() {

    return (
      <div>

        <TrackOrderResult show={this.state.show} business={this.state.business_name} />
        {!this.state.show && <div>
          {/* <!-- INFO BAR --> */}
          <div class="bg-yellow-600 ">
            <div class="flex flex-col px-6 py-3">

              <h1 class="text-2xl text-yellow-100 font-bold">
                Let's get started</h1>
              <p class="text-xs text-yellow-200 font-medium">
                Provide your business information</p>

            </div>
          </div>
          {/* <!-- END INFO BAR -->
              <!-- BODY FORM --> */}
          <div class="p-6 overflow-y">
            <form onSubmit={this.onSubmit}>

              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ business_name: event.target.value })} type="text" name="name" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="name" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Business
                      Name</label>
                <span class="text-sm text-red-600 hidden" id="error">Business Name is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ email: event.target.value })} type="text" name="email" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="email" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Email</label>
                <span class="text-sm text-red-600 hidden" id="error">Business email is
                      required</span>
              </div>
              <div class="relative z-0 w-full mb-5">
                <input onChange={event => this.setState({ phone_number: event.target.value })}
                  type="text" name="phone" placeholder=" " required
                  class="pt-3 pb-2 block w-full px-0 mt-0 bg-transparent border-0 border-b-2 appearance-none focus:outline-none focus:ring-0 focus:border-black border-gray-200" />
                <label for="phone" class="absolute duration-300 top-0 -z-1 origin-0 text-gray-500">Phone Number</label>
                <span class="text-sm text-red-600 hidden" id="error">Phone number is
                      required</span>
              </div>

              <button id="button" type="submit"
                class="w-90 px-6 py-1 mt-3 text-lg text-yellow-100 transition-all duration-150 ease-linear  shadow-sm rounded-full outline-none bg-yellow-600 hover:bg-yellow-700 hover:shadow-lg focus:outline-none tracking-wide">
                {this.state.isLoading ? "submitting application..." : "Submit"}
              </button>

            </form>
          </div>
        </div>
        }
      </div>
    )
  }
}
// Gold Form
// silver modal
function App() {

  return (
    <div>
      <ApplicantForm />
    </div>
  );
}
// platinum modal
function App2() {
  return (
    <div>
      <ApplicantFormPlatinum />
    </div>
  );
}
// Gold model
function App3() {
  return (
    <div>
      <ApplicantFormGold />
    </div>
  );
}
ReactDOM.render(
  <App />,
  document.getElementById('silver')
);
ReactDOM.render(
  <App2 />,
  document.getElementById('platinum')
);
ReactDOM.render(
  <App3 />,
  document.getElementById('gold')
);